@@ -86,6 +86,11 @@ class ImplementationConfig(BaseConfigSection):
         with increased memory costs.
         """
 
+        self._debug_mode_type = bool
+        self.debug_mode = False
+        """bool: A flag to run the code in debug mode, which circumvents ray.
+        """
+
 
         self.set_config_options(sub_configdic)
 
