@@ -30,7 +30,6 @@ import matplotlib
 import pylab as plt
 from isofit.configs import configs
 import ray
-import ray.services
 import atexit
 from isofit.core.common import envi_header
 
@@ -368,15 +367,9 @@ def empirical_line(reference_radiance_file: str, reference_reflectance_file: str
     rayargs = {'ignore_reinit_error': iconfig.implementation.ray_ignore_reinit_error,
                'local_mode': n_cores == 1,
                "address": iconfig.implementation.ip_head,
+               '_temp_dir': iconfig.implementation.ray_temp_dir,
                "_redis_password": iconfig.implementation.redis_password}
 
-    # only specify a temporary directory if we are not connecting to
-    # a ray cluster
-    if rayargs['local_mode']:
-        rayargs['_temp_dir'] = iconfig.implementation.ray_temp_dir
-        # Used to run on a VPN
-        ray.services.get_node_ip_address = lambda: '127.0.0.1'
-
     # We can only set the num_cpus if running on a single-node
     if iconfig.implementation.ip_head is None and iconfig.implementation.redis_password is None:
         rayargs['num_cpus'] = n_cores
